import { getContextItem } from "./context.ts";

export abstract class Drawable {
  abstract draw(...args: unknown[]): void;
}

export abstract class Debuggable extends Drawable {
  constructor(...debugKeys: (keyof Debug)[]) {
    super();
    if (import.meta.env.DEV) {
      const draw = this.draw.bind(this);
      console.log("Adding debug draw");
      this.draw = (...args: unknown[]) => {
        draw(...args);
        const debug = getContextItem<Debug>("debug");
        if (debugKeys.some((k) => debug[k])) {
          this.debugDraw(...args);
        }
      };
    }
  }

  abstract debugDraw(...args: unknown[]): void;
}
